@@ -221,13 +221,12 @@ test_that("classification models generate correct error message", {
   expect_length(notes, 2L)
 
   # Known failure in the recipe
-  expect_true(all(grepl("outcome should be a factor", note)))
+  expect_true(all(grepl("outcome should be a `factor`", note)))
 
   expect_equal(extract, list(NULL, NULL))
   expect_equal(predictions, list(NULL, NULL))
 })
 
-
 # tune_grid() fallback ---------------------------------------------------------
 
 test_that("`tune_grid()` falls back to `fit_resamples()` - formula", {
